====================
Beam Section Profile
====================

The Beam Section profile commands are used to create profiles. A profile definition specifies the properties of a beam that are related to its cross-section geometry. When you define a beam section, you must include a reference to a profile in the section definition.

Create beam section profiles
----------------------------

In Mdb
~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.BeamSectionProfileModel.BeamSectionProfileModel
    :noindex:

    .. autoclasstoc::

In Odb
~~~~~~

.. autoclass:: abaqus.BeamSectionProfile.BeamSectionProfileOdb.BeamSectionProfileOdb
    :noindex:

    .. autoclasstoc::
